@@ -96,7 +96,7 @@ def get_index(doc_name, retro_page, collaborative, base_url="/"):
     page_config = {
         "appName": "RetroLab",
         "appNamespace": "retro",
-        "appSettingsDir": str(prefix_dir / "share" / "jupyter" / "lab" / "settings"),
+        "appSettingsDir": (prefix_dir / "share" / "jupyter" / "lab" / "settings").as_posix(),
         "appUrl": "/lab",
         "appVersion": retrolab.__version__,
         "baseUrl": base_url,
@@ -117,19 +117,19 @@ def get_index(doc_name, retro_page, collaborative, base_url="/"):
         "fullTranslationsApiUrl": f"{base_url}lab/api/translations",
         "fullTreeUrl": f"{base_url}lab/tree",
         "fullWorkspacesApiUrl": f"{base_url}lab/api/workspaces",
-        "labextensionsPath": [str(prefix_dir / "share" / "jupyter" / "labextensions")],
+        "labextensionsPath": [(prefix_dir / "share" / "jupyter" / "labextensions").as_posix()],
         "labextensionsUrl": "/lab/extensions",
         "licensesUrl": "/lab/api/licenses",
         "listingsUrl": "/lab/api/listings",
         "mathjaxConfig": "TeX-AMS-MML_HTMLorMML-full,Safe",
         "retroLogo": False,
         "retroPage": retro_page,
-        "schemasDir": str(prefix_dir / "share" / "jupyter" / "lab" / "schemas"),
+        "schemasDir": (prefix_dir / "share" / "jupyter" / "lab" / "schemas").as_posix(),
         "settingsUrl": "/lab/api/settings",
-        "staticDir": str(retrolab_dir / "static"),
-        "templatesDir": str(retrolab_dir / "templates"),
+        "staticDir": (retrolab_dir / "static").as_posix(),
+        "templatesDir": (retrolab_dir / "templates").as_posix(),
         "terminalsAvailable": True,
-        "themesDir": str(prefix_dir / "share" / "jupyter" / "lab" / "themes"),
+        "themesDir": (prefix_dir / "share" / "jupyter" / "lab" / "themes").as_posix(),
         "themesUrl": "/lab/api/themes",
         "translationsApiUrl": "/lab/api/translations",
         "treeUrl": "/lab/tree",
